"""
db4e/Templates/db/MongoRecords.py

    Database 4 Everything
    Author: Nadim-Daniel Ghaznavi 
    Copyright (c) 2024-2025 NadimGhaznavi <https://github.com/NadimGhaznavi/db4e>
    License: GPL 3.0

This module contains templates for the Mongo deployment record types.
"""

from db4e.Constants.Defaults import (
    ANY_IP_DEFAULT, DONATION_WALLET_DEFAULT, IN_PEERS_DEFAULT, LOCALHOST_DEFAULT, 
    LOG_LEVEL_DEFAULT, MAX_LOG_FILES_DEFAULT, MAX_LOG_SIZE_DEFAULT, MONEROD_CONFIG_DEFAULT, 
    MONEROD_LOG_FILE_DEFAULT, OUT_PEERS_DEFAULT, P2P_BIND_PORT_DEFAULT, PRIORITY_NODE_1_DEFAULT, PRIORITY_NODE_2_DEFAULT, 
    RPC_BIND_PORT_DEFAULT, SERVICE_STATUS_DEFAULT, SHOW_TIME_STATS_FIELD_DEFAULT, 
    STRATUM_PORT_DEFAULT, ZMQ_PUB_PORT_DEFAULT, ZMQ_RPC_PORT_DEFAULT
)

from db4e.Constants.Labels import DB4E_LABEL, MONEROD_LABEL, P2POOL_LABEL, XMRIG_LABEL

from db4e.Constants.Fields import (
    ANY_IP_FIELD, DB4E_FIELD, CHAIN_FIELD, CONFIG_FIELD, COMPONENT_FIELD, DATA_DIR_FIELD, 
    DONATION_WALLET_FIELD, ENABLE_FIELD, GROUP_FIELD, IN_PEERS_FIELD, INSTALL_DIR_FIELD, 
    INSTANCE_FIELD, IP_ADDR_FIELD, LOG_LEVEL_FIELD, LOG_NAME_FIELD, MAX_LOG_FILES_FIELD, 
    MAX_LOG_SIZE_FIELD, MONEROD_FIELD, MONEROD_ID_FIELD, NAME_FIELD, NUM_THREADS_FIELD, OP_FIELD, 
    OUT_PEERS_FIELD, P2P_BIND_PORT_FIELD, P2P_PORT_FIELD, P2POOL_FIELD, P2POOL_ID_FIELD, 
    PRIORITY_NODE_1_FIELD, PRIORITY_NODE_2_FIELD, PRIORITY_PORT_1_FIELD, 
    PRIORITY_PORT_2_FIELD, REMOTE_FIELD, RPC_BIND_PORT_FIELD, SHOW_TIME_STATS_FIELD, 
    STATUS_FIELD, STRATUM_PORT_FIELD, UPDATED_FIELD, USER_FIELD, USER_WALLET_FIELD, 
    VENDOR_DIR_FIELD, VERSION_FIELD, WALLET_FIELD, XMRIG_FIELD, ZMQ_PUB_PORT_FIELD, 
    ZMQ_RPC_PORT_FIELD)

## The DbMgr uses these "Templates" to create new records
# Db4E Core 
Db4E_Record_Template = {
    COMPONENT_FIELD: DB4E_FIELD,
    DONATION_WALLET_FIELD: DONATION_WALLET_DEFAULT,
    ENABLE_FIELD: None,
    GROUP_FIELD: None,
    INSTALL_DIR_FIELD: None,
    NAME_FIELD: DB4E_LABEL,
    OP_FIELD: None,
    STATUS_FIELD: None,
    UPDATED_FIELD: None,
    USER_FIELD: None,
    USER_WALLET_FIELD: None,
    VENDOR_DIR_FIELD: None,
    VERSION_FIELD: None,
    }
# Remote Monero Daemon Instance
MoneroD_Remote_Record_Template = {
    COMPONENT_FIELD: MONEROD_FIELD,
    ENABLE_FIELD: None,
    INSTANCE_FIELD: None,
    IP_ADDR_FIELD: None,
    NAME_FIELD: MONEROD_LABEL,
    OP_FIELD: None,
    REMOTE_FIELD: True,
    RPC_BIND_PORT_FIELD: RPC_BIND_PORT_DEFAULT,
    STATUS_FIELD: None,
    UPDATED_FIELD: None,
    ZMQ_PUB_PORT_FIELD: ZMQ_PUB_PORT_DEFAULT,
    }


MoneroD_Record_Template = {
    COMPONENT_FIELD: MONEROD_FIELD,
    CONFIG_FIELD: MONEROD_CONFIG_DEFAULT,
    DATA_DIR_FIELD: None,
    ENABLE_FIELD: None,
    IN_PEERS_FIELD: IN_PEERS_DEFAULT,
    INSTANCE_FIELD: None,
    IP_ADDR_FIELD: None,
    LOG_LEVEL_FIELD: LOG_LEVEL_DEFAULT,
    LOG_NAME_FIELD: MONEROD_LOG_FILE_DEFAULT,
    MAX_LOG_FILES_FIELD: MAX_LOG_FILES_DEFAULT,
    MAX_LOG_SIZE_FIELD: MAX_LOG_SIZE_DEFAULT,
    NAME_FIELD: MONEROD_LABEL,
    OP_FIELD: None,
    OUT_PEERS_FIELD: OUT_PEERS_DEFAULT,
    P2P_BIND_PORT_FIELD: P2P_BIND_PORT_DEFAULT,
    PRIORITY_NODE_1_FIELD: PRIORITY_NODE_1_DEFAULT,
    PRIORITY_NODE_2_FIELD: PRIORITY_NODE_2_DEFAULT,
    PRIORITY_PORT_1_FIELD: P2P_BIND_PORT_DEFAULT,
    PRIORITY_PORT_2_FIELD: P2P_BIND_PORT_DEFAULT,
    REMOTE_FIELD: False,
    RPC_BIND_PORT_FIELD: RPC_BIND_PORT_DEFAULT,
    SHOW_TIME_STATS_FIELD: SHOW_TIME_STATS_FIELD_DEFAULT,
    STATUS_FIELD: None,
    UPDATED_FIELD: None,
    VERSION_FIELD: None,
    ZMQ_PUB_PORT_FIELD: ZMQ_PUB_PORT_DEFAULT,
    ZMQ_RPC_PORT_FIELD: ZMQ_RPC_PORT_DEFAULT,
    }

P2Pool_Remote_Record_Template = {
    COMPONENT_FIELD: P2POOL_FIELD,
    ENABLE_FIELD: None,
    INSTANCE_FIELD: None,
    IP_ADDR_FIELD: None,
    NAME_FIELD: P2POOL_LABEL,
    OP_FIELD: None,
    REMOTE_FIELD: True,
    STATUS_FIELD: None,
    STRATUM_PORT_FIELD: STRATUM_PORT_DEFAULT,
    UPDATED_FIELD: None,
    }

P2Pool_Record_Template = {
    ANY_IP_FIELD: ANY_IP_DEFAULT,
    CHAIN_FIELD: None,
    COMPONENT_FIELD: P2POOL_FIELD,
    CONFIG_FIELD: None,
    ENABLE_FIELD: None,
    IN_PEERS_FIELD: IN_PEERS_DEFAULT,
    INSTANCE_FIELD: None,
    IP_ADDR_FIELD: LOCALHOST_DEFAULT,
    LOG_LEVEL_FIELD: LOG_LEVEL_DEFAULT,
    MONEROD_ID_FIELD: None,
    NAME_FIELD: P2POOL_LABEL,
    OP_FIELD: None,
    OUT_PEERS_FIELD: OUT_PEERS_DEFAULT,
    P2P_PORT_FIELD: P2P_BIND_PORT_DEFAULT,
    REMOTE_FIELD: False,
    STATUS_FIELD: SERVICE_STATUS_DEFAULT,
    STRATUM_PORT_FIELD: STRATUM_PORT_DEFAULT,
    UPDATED_FIELD: None,
    VERSION_FIELD: None,
    WALLET_FIELD: None,
    }

XMRig_Record_Template = {
    COMPONENT_FIELD: XMRIG_FIELD,
    CONFIG_FIELD: None,
    ENABLE_FIELD: None,
    INSTANCE_FIELD: None,
    NAME_FIELD: XMRIG_LABEL,
    NUM_THREADS_FIELD: None,
    OP_FIELD: None,
    P2POOL_ID_FIELD: None,
    REMOTE_FIELD: False,
    STATUS_FIELD: SERVICE_STATUS_DEFAULT,
    UPDATED_FIELD: None,
    VERSION_FIELD: None,
    }
